import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { fromJS } from 'immutable'

import MkIcon from '@/components/mk-icon'
import Utils from '@/utils/utils.js'
import ColumnForm from './columnform'
import asyncComponent from '@/utils/asyncComponent'
// import './index.scss'

const EditTable = asyncComponent(() => import('@/templates/zshare/editTable'))

class CardMenus extends Component {
  static propTpyes = {
    appType: PropTypes.string,
    menulist: PropTypes.array,
    menus: PropTypes.array,
    update: PropTypes.func
  }

  state = {
    columns: [
      {
        title: '标识',
        dataIndex: 'sign',
        inputType: 'input',
        editable: true,
        unique: true,
        required: false,
        width: '20%'
      },
      {
        title: '颜色',
        dataIndex: 'color',
        inputType: 'color',
        editable: true,
        required: true,
        width: '20%',
        render: (text, record) => <span style={{display: 'inline-block', width: '40px', height: '25px', background: text}}></span>
      },
      {
        title: '图标',
        dataIndex: 'icon',
        inputType: 'icon',
        editable: true,
        required: false,
        width: '20%',
        render: (text, record) => record.icon ? <MkIcon style={{fontSize: '24px'}} type={record.icon}/> : ''
      },
      {
        title: '连接线',
        dataIndex: 'linecolor',
        inputType: 'color',
        editable: true,
        required: false,
        allowClear: true,
        width: '20%',
        render: (text, record) => text ? <span style={{display: 'inline-block', width: '40px', height: '25px', background: text}}></span> : null
      },
      {
        title: '备注',
        dataIndex: 'remark',
        inputType: 'input',
        editable: true,
        required: false,
        width: '20%'
      }
    ]
  }

  UNSAFE_componentWillMount() {
    const { menus } = this.props

    this.setState({
      menus: fromJS(menus).toJS()
    })
  }

  columnChange = (values) => {
    const { menus } = this.state
    values.uuid = Utils.getuuid()
    let _menus = [...menus, values]

    this.setState({menus: _menus})
    this.props.update(_menus)
  }

  changeColumns = (columns) => {
    this.setState({menus: columns})
    this.props.update(columns)
  }

  render() {
    const { menus, columns } = this.state

    return (
      <div style={{minHeight: '250px'}}>
        <ColumnForm menus={menus} columnChange={this.columnChange}/>
        <p style={{position: 'absolute', fontSize: '12px', transform: 'translate(0px, -20px)'}}>连接线在横向时间轴中有效</p>
        <EditTable actions={['edit', 'move', 'copy', 'del']} type={'timenodes'} data={menus} columns={columns} onChange={this.changeColumns}/>
      </div>
    )
  }
}

export default CardMenus